<?php

namespace Drupal\cloudwords\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element;
use Drupal\cloudwords\CloudwordsDrupalProject;
use Drupal\cloudwords\CloudwordsLanguage;

class CloudwordsProjectLanguageForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cloudwords_project_language_form';
  }

  public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state, CloudwordsDrupalProject $cloudwords_project = NULL, CloudwordsLanguage $cloudwords_language = NULL) {
    $rows = [];

    $header_row = [
      ['data' => 'Source name', 'field' => 'ct.label'],
      [
        'data' => 'Group',
        'field' => 'ct.textgroup',
      ],
      ['data' => 'type', 'field' => 'ct.type'],
      [
        'data' => 'Translation status',
        'field' => 'ct.translation_status',
      ],
      ['data' => 'Import status', 'field' => 'cc.status'],
    ];

    $query = \Drupal::database()->select('cloudwords_translatable', 'ct')
      ->fields('ct')
      ->condition('ct.language', cloudwords_map_cloudwords_drupal($cloudwords_language->getLanguageCode()));

    $query->addJoin('INNER', 'cloudwords_content', 'cc', 'ct.id = cc.ctid');
    $query->fields('cc', ['status']);
    $query->condition('cc.pid', $cloudwords_project->getId());

    $results = $query->execute();

    foreach ($results as $result) {
      $translatable = cloudwords_translatable_load($result->id);
      $row = [];

      $row['label'] = '';//$translatable->editLink();
      $row['group'] = '';//$translatable->textGroupLabel();
      $row['type'] = $translatable->typeLabel();
      $row['translation_status'] = '';//$translatable->translationStatusLabel();

      switch ($result->status) {
        case CLOUDWORDS_LANGUAGE_NOT_IMPORTED:
          $status = $this->t('Not imported');
          break;

        case CLOUDWORDS_LANGUAGE_IMPORTED:
          $status = $this->t('Imported');
          break;

        case CLOUDWORDS_LANGUAGE_FAILED:
          $status = '<span class="marker">' . $this->t('Import failed') . '</span>';
          break;
      }

      $row['status'] = $status;
      $rows[$translatable->ctid] = $row;
    }

    $form['table'] = [
      '#theme' => 'table',
      '#header' => $header_row,
      '#rows' => $rows,
      '#attributes' => [
        'id' => 'cloudwords-project-table'
        ],
      '#empty' => $this->t('No content available.'),
    ];

    return $form;
  }
  public function validateForm(array &$form, FormStateInterface $form_state) {
    // Validate submitted form data.
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Handle submitted form data.
  }

}
